// GENPO - the GENeral Purpose Organ
// Copyright (C) 2003,2004,2007 - Steve Merrony 

/* This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/> or
    write to the Free Software Foundation, 51 Franklin Street, Fifth Floor, 
    Boston, MA 02110-1301, USA
*/

#ifndef STOP_H
#define STOP_H

#include <qcolor.h>
#include <qstring.h>

class Stop {
 public:
  QString label;
  QString name;
  QColor  colour;
  bool    isReed;
  int     midiBank;
  int     midiVoice;
  bool    pulled;
  unsigned char velocity;
  int     kbdMidiChannel;  // set by the progam when stop is pulled
  int     voiceIndex;           // index of the voice assigned
};

#endif
